==> ghc-6.12.3p8.tgz: lib/ghc/process-1.0.1.3/include/runProcess.h <==
/* ----------------------------------------------------------------------------
   (c) The University of Glasgow 2004

   Interface for code in runProcess.c (providing support for System.Process)
   ------------------------------------------------------------------------- */

#include "HsProcessConfig.h"
// Otherwise these clash with similar definitions from other packages:
#undef PACKAGE_BUGREPORT
#undef PACKAGE_NAME
#undef PACKAGE_STRING
#undef PACKAGE_TARNAME
#undef PACKAGE_VERSION

#if defined(_MSC_VER) || defined(__MINGW32__) || defined(_WIN32)
#define UNICODE
#include <windows.h>
#include <stdlib.h>
#endif

#include <unistd.h>
#include <sys/types.h>

#ifdef HAVE_FCNTL_H
#include <fcntl.h>
#endif

#ifdef HAVE_VFORK_H
#include <vfork.h>
#endif

#ifdef HAVE_VFORK
#define fork vfork
#endif

#ifdef HAVE_SIGNAL_H
#include <signal.h>
#endif

#if !(defined(_MSC_VER) || defined(__MINGW32__) || defined(_WIN32))
typedef pid_t ProcHandle;
#else
// Should really be intptr_t, but we don't have that type on the Haskell side
typedef long ProcHandle;
#endif

#if !(defined(_MSC_VER) || defined(__MINGW32__) || defined(_WIN32))

extern ProcHandle runInteractiveProcess( char *const args[], 
					 char *workingDirectory, 
					 char **environment, 
                                         int fdStdIn, int fdStdOut, int fdStdErr,
					 int *pfdStdInput, 
					 int *pfdStdOutput, 
					 int *pfdStdError,
                                         int set_inthandler, long inthandler, 
                                         int set_quithandler, long quithandler,
                                         int close_fds);

#else

extern ProcHandle runInteractiveProcess( wchar_t *cmd,
					 wchar_t *workingDirectory,
					 void *environment,
                                         int fdStdIn, int fdStdOut, int fdStdErr,
					 int *pfdStdInput,
					 int *pfdStdOutput,
					 int *pfdStdError,
                                         int close_fds);

#endif

extern int terminateProcess( ProcHandle handle );
extern int getProcessExitCode( ProcHandle handle, int *pExitCode );
extern int waitForProcess( ProcHandle handle );

==> ghc-7.0.4p0.tgz: lib/ghc/process-1.0.1.5/include/runProcess.h <==
/* ----------------------------------------------------------------------------
   (c) The University of Glasgow 2004

   Interface for code in runProcess.c (providing support for System.Process)
   ------------------------------------------------------------------------- */

#include "HsProcessConfig.h"
// Otherwise these clash with similar definitions from other packages:
#undef PACKAGE_BUGREPORT
#undef PACKAGE_NAME
#undef PACKAGE_STRING
#undef PACKAGE_TARNAME
#undef PACKAGE_VERSION

#if defined(_MSC_VER) || defined(__MINGW32__) || defined(_WIN32)
#define UNICODE
#include <windows.h>
#include <stdlib.h>
#endif

#include <unistd.h>
#include <sys/types.h>

#ifdef HAVE_FCNTL_H
#include <fcntl.h>
#endif

#ifdef HAVE_SIGNAL_H
#include <signal.h>
#endif

#if !(defined(_MSC_VER) || defined(__MINGW32__) || defined(_WIN32))
typedef pid_t ProcHandle;
#else
// Should really be intptr_t, but we don't have that type on the Haskell side
typedef long ProcHandle;
#endif

#if !(defined(_MSC_VER) || defined(__MINGW32__) || defined(_WIN32))

extern ProcHandle runInteractiveProcess( char *const args[], 
					 char *workingDirectory, 
					 char **environment, 
                                         int fdStdIn, int fdStdOut, int fdStdErr,
					 int *pfdStdInput, 
					 int *pfdStdOutput, 
					 int *pfdStdError,
                                         int set_inthandler, long inthandler, 
                                         int set_quithandler, long quithandler,
                                         int close_fds);

#else

extern ProcHandle runInteractiveProcess( wchar_t *cmd,
					 wchar_t *workingDirectory,
					 void *environment,
                                         int fdStdIn, int fdStdOut, int fdStdErr,
					 int *pfdStdInput,
					 int *pfdStdOutput,
					 int *pfdStdError,
                                         int close_fds);

#endif

extern int terminateProcess( ProcHandle handle );
extern int getProcessExitCode( ProcHandle handle, int *pExitCode );
extern int waitForProcess( ProcHandle handle, int *ret );
